@@ -4,12 +4,20 @@
 # @Author  : mtl
 # @File    : example.py
 # @Description : *****
-import traceback
+import collections
 from pathlib import Path
 
 from openpyxl import load_workbook
+from openpyxl.worksheet.worksheet import Worksheet
 
-from simple_export.excel import write_excel_for_template
+from excel import write_excel_for_template
+from simple_export.utils.util import dynamic_method
+class dynamic_method2(dynamic_method):
+    def abc(self, coordinate: str, sheet: Worksheet, pos_mapping: collections.defaultdict, pos: collections.defaultdict ):
+        print("abc")
+
+    def get_sum(self, coordinate: str, sheet: Worksheet, pos_mapping: collections.defaultdict, pos: collections.defaultdict, a):
+        print("abc")
 
 def test1():
     wb_tmp = load_workbook(Path(__file__).parent / 'template/excel1.xlsx')
@@ -397,7 +405,7 @@ def test3():
                 'row3_sum': 0, 'row_sum': 15529.36, 'month': '环境保护税按月计算报表（2）月',
                 'title': '税款所属期：自2023年02月01日至2023年02月28日'}}
     wb_tmp = load_workbook(Path(__file__).parent / 'template/excel5.xlsx')
-    write_excel_for_template(value=value, wb_tmp=wb_tmp, convert_pic=True)
+    write_excel_for_template(value=value, wb_tmp=wb_tmp, convert_pic=True, dynamic_method=dynamic_method2())
     wb_tmp.save("./val3.xlsx")
 
 if __name__ == '__main__':
